@@ -1,8 +1,8 @@
 import logging
 from typing import Optional, List
 
-import annotell.input_api.model.input as InputModel
-import annotell.input_api.model.input.lidars_and_cameras as LCModel
+import annotell.input_api.model.input as input_model
+import annotell.input_api.model.input.lidars_and_cameras as lc_model
 from annotell.input_api.resources.abstract import CreateableInputAPIResource
 
 log = logging.getLogger(__name__)
@@ -13,11 +13,11 @@ class LidarsAndCameras(CreateableInputAPIResource):
     path = 'lidars-and-cameras'
 
     def create(self,
-               lidars_and_cameras: LCModel.LidarsAndCameras,
+               lidars_and_cameras: lc_model.LidarsAndCameras,
                project: Optional[str] = None,
                batch: Optional[str] = None,
                annotation_types: Optional[List[str]] = None,
-               dryrun: bool = False) -> Optional[InputModel.CreateInputResponse]:
+               dryrun: bool = False) -> Optional[input_model.CreateInputResponse]:
         """
         Upload files and create an input of type ``LidarsAndCameras``.
 
@@ -42,4 +42,4 @@ class LidarsAndCameras(CreateableInputAPIResource):
 
         log.info(
             f"Created inputs for files with uuid={response.input_uuid}")
-        return InputModel.CreateInputResponse.from_input_job_response(response)
+        return input_model.CreateInputResponse.from_input_job_response(response)
